summaryrefslogtreecommitdiff
path: root/lib-src
diff options
context:
space:
mode:
authorRichard M. Stallman <rms@gnu.org>1994-04-30 20:30:48 +0000
committerRichard M. Stallman <rms@gnu.org>1994-04-30 20:30:48 +0000
commit6efb177025bc496802e6bc30fa8681e7b704556f (patch)
tree937133780be751f2674d8fb2c988adca391e0961 /lib-src
parent6f17d2397870dc96eb2c568912bd2a15aaf0c01b (diff)
downloademacs-6efb177025bc496802e6bc30fa8681e7b704556f.tar.gz
(find_entries): Treat `*.cpp' as C++ files.
Diffstat (limited to 'lib-src')
-rw-r--r--lib-src/etags.c3
1 files changed, 2 insertions, 1 deletions
diff --git a/lib-src/etags.c b/lib-src/etags.c
index bae7e17207a..1ae77e7f2be 100644
--- a/lib-src/etags.c
+++ b/lib-src/etags.c
@@ -783,9 +783,10 @@ find_entries (file)
Asm_labels (inf);
goto close_and_return;
}
/* .C or .H or .cxx or .hxx or .cc: a C++ file */
if (cp && (streq (cp1, "C")
|| streq (cp1, "H")
+ || streq (cp1, "cpp")
|| streq (cp1, "cxx")
|| streq (cp1, "hxx")
|| streq (cp1, "cc")))
@@ -783,9 +783,10 @@ find_entries (file)
goto close_and_return;
}
- /* .C or .H or .cxx or .hxx or .cc: a C++ file */
+ /* .C or .H or .cxx or .hxx or .cc or .cpp: a C++ file */
if (cp && (streq (cp1, "C")
|| streq (cp1, "H")